@@ -14,3 +14,5 @@ pos_dodge <- utils::getFromNamespace("pos_dodge", "ggplot2")
 pos_dodge2 <- utils::getFromNamespace("pos_dodge2", "ggplot2")
 new_mapped_discrete <- utils::getFromNamespace("new_mapped_discrete", "ggplot2")
 is_mapped_discrete <- utils::getFromNamespace("is_mapped_discrete", "ggplot2")
+dapply <- utils::getFromNamespace("dapply", "ggplot2")
+empty <- utils::getFromNamespace("empty", "ggplot2")
